
#ifndef CDLGSMS_H
#define CDLGSMS_H

#include <QDialog>
#include <QWidget>
#include <ui_IDlgSms.h>


class CDlgSms : public QDialog, private Ui::IDlgSms
{
    Q_OBJECT;
        public:
            CDlgSms(QWidget *parent);
            virtual ~CDlgSms();
        private:

        private slots:

};

#endif // CDLGSMS_H
